@@ -1225,8 +1225,7 @@ void KAEventTest::toKCalEvent()
 
     {
         // Event category, UID, revision, start time using time zone, created time
-        KAEvent event;
-        event.set(dt, text, bgColour, fgColour, font, KAEvent::MESSAGE, 3, KAEvent::CONFIRM_ACK);
+        KAEvent event(dt, text, bgColour, fgColour, font, KAEvent::MESSAGE, 3, KAEvent::CONFIRM_ACK);
         event.setEventId(uid);
         event.incrementRevision();
         event.incrementRevision();
@@ -1254,8 +1253,7 @@ void KAEventTest::toKCalEvent()
     {
         // Start time using LocalZone
         const KADateTime dt(QDate(2010,5,13), QTime(3, 45, 0), KADateTime::LocalZone);
-        KAEvent event;
-        event.set(dt, text, bgColour, fgColour, font, KAEvent::MESSAGE, 3, KAEvent::CONFIRM_ACK);
+        KAEvent event(dt, text, bgColour, fgColour, font, KAEvent::MESSAGE, 3, KAEvent::CONFIRM_ACK);
         event.setEventId(uid);
         event.incrementRevision();
         event.setCategory(CalEvent::ACTIVE);
@@ -1267,7 +1265,7 @@ void KAEventTest::toKCalEvent()
         QCOMPARE(kcalevent->customProperty("KALARM", "TYPE"), QStringLiteral("ACTIVE"));
         QStringList flags = kcalevent->customProperty("KALARM", "FLAGS").split(SC);
         QCOMPARE(flags.size(), 4);   // must contain LOCAL, LATECANCEL;3 and ACKCONF
-        QVERIFY(flags.contains(QStringLiteral("LOCAL")));
+        QVERIFY(flags.contains(QLatin1String("LOCAL")));
         const QDateTime dtCurrentTz(dt.date(), dt.time(), QTimeZone::systemTimeZone());
         QCOMPARE(kcalevent->dtStart(), dtCurrentTz);
         QCOMPARE(kcalevent->created(), createdDt.qDateTime());
