@@ -2,7 +2,7 @@
  *  compatibilityattribute.h  -  Akonadi attribute holding Collection compatibility
  *  This file is part of kalarmcal library, which provides access to KAlarm
  *  calendar data.
- *  Copyright © 2011 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2011-2019 David Jarvie <djarvie@kde.org>
  *
  *  This library is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Library General Public License as published
@@ -58,6 +58,10 @@ public:
 
     ~CompatibilityAttribute() override;
 
+    /** Comparison operator. */
+    bool operator==(const CompatibilityAttribute &other) const;
+    bool operator!=(const CompatibilityAttribute &other) const  { return !operator==(other); }
+
     /** Return the compatibility status for the entity. */
     KACalendar::Compat compatibility() const;
 
@@ -97,3 +101,4 @@ private:
 
 #endif // KALARM_COMPATIBILITY_ATTRIBUTE_H
 
+// vim: et sw=4:
