@@ -25,8 +25,6 @@
 #include "kaevent.h"
 #include "version.h"
 
-#include "collectionattribute.h"
-
 #include <kcalendarcore/event.h>
 #include <kcalendarcore/alarm.h>
 #include <kcalendarcore/memorycalendar.h>
@@ -40,7 +38,6 @@
 #include <QTextStream>
 
 using namespace KCalendarCore;
-using Akonadi::Collection;
 
 namespace KAlarmCal
 {
@@ -121,8 +118,10 @@ int updateVersion(const FileStorage::Ptr &fileStorage, QString &versionString)
         qCDebug(KALARMCAL_LOG) << "KAlarm version" << version;
     }
 
-    // Convert events to current KAlarm format for when/if the calendar is saved
+    // Convert events to current KAlarm format for when/if the calendar is saved.
     KAEvent::convertKCalEvents(fileStorage->calendar(), ver);
+    // Set the new calendar version.
+    setKAlarmVersion(fileStorage->calendar());
     return version;
 }
 
@@ -178,7 +177,7 @@ int Private::readKAlarmVersion(const FileStorage::Ptr &fileStorage, QString &sub
         if (i <= 0) {
             return KACalendar::IncompatibleFormat;    // missing version string
         }
-        versionString = versionString.left(i);   // 'versionString' now contains the KAlarm version string
+        versionString.truncate(i);   // 'versionString' now contains the KAlarm version string
     }
     if (versionString == QLatin1String(KAEvent::currentCalendarVersionString())) {
         return KACalendar::CurrentFormat;    // the calendar is in the current KAlarm format
