@@ -2,7 +2,7 @@
  *  kacalendar.h  -  KAlarm kcal library calendar and event categorisation
  *  This file is part of kalarmcal library, which provides access to KAlarm
  *  calendar data.
- *  Copyright © 2005-2012 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2005-2019 David Jarvie <djarvie@kde.org>
  *
  *  This library is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Library General Public License as published
@@ -24,15 +24,17 @@
 #define KALARM_KACALENDAR_H
 
 #include "kalarmcal_export.h"
-#include <kcalcore/filestorage.h>
-#include <kcalcore/calendar.h>
-#include <kcalcore/event.h>
-#include <collection.h>
+
+#include <kcalendarcore/filestorage.h>
+#include <kcalendarcore/calendar.h>
+#include <kcalendarcore/event.h>
+
+#include <AkonadiCore/Collection>
 
 #include <QByteArray>
 #include <QStringList>
 
-namespace KCalCore
+namespace KCalendarCore
 {
 class Alarm;
 }
@@ -45,6 +47,9 @@ extern const QLatin1String KALARMCAL_EXPORT MIME_ACTIVE;    //!< The mime type f
 extern const QLatin1String KALARMCAL_EXPORT MIME_ARCHIVED;  //!< The mime type for KAlarm archived alarms
 extern const QLatin1String KALARMCAL_EXPORT MIME_TEMPLATE;  //!< The mime type for KAlarm alarm templates
 
+/** Declaration type for a calendar resource ID. */
+typedef Akonadi::Collection::Id  ResourceId;
+
 /**
  * @short Class representing attributes of a KAlarm calendar.
  *
@@ -80,18 +85,17 @@ enum {
  *  file is not updated. The compatibility of the calendar format is
  *  indicated by the return value.
  *
- *  @param calendar       calendar stored in @p localFile
- *  @param localFile      full path of the calendar's file storage
+ *  @param fileStorage    calendar stored in local file
  *  @param versionString  receives calendar's KAlarm version as a string
  *  @return CurrentFormat if the calendar is in the current KAlarm format;
  *          IncompatibleFormat calendar is not a KAlarm format or is an
                                unknown KAlarm format;
  *          >0 the older KAlarm version which wrote the calendar
  */
-KALARMCAL_EXPORT int updateVersion(const KCalCore::FileStorage::Ptr &, QString &versionString);
+KALARMCAL_EXPORT int updateVersion(const KCalendarCore::FileStorage::Ptr &, QString &versionString);
 
 /** Set the KAlarm version custom property for a calendar. */
-KALARMCAL_EXPORT void setKAlarmVersion(const KCalCore::Calendar::Ptr &);
+KALARMCAL_EXPORT void setKAlarmVersion(const KCalendarCore::Calendar::Ptr &);
 
 /** Set the program name and version for use in calendars. */
 KALARMCAL_EXPORT void setProductId(const QByteArray &progName, const QByteArray &progVersion);
@@ -128,8 +132,8 @@ enum Type {
 Q_DECLARE_FLAGS(Types, Type)
 
 KALARMCAL_EXPORT QString uid(const QString &id, Type);
-KALARMCAL_EXPORT Type    status(const KCalCore::Event::Ptr &, QString *param = nullptr);
-KALARMCAL_EXPORT void    setStatus(const KCalCore::Event::Ptr &, Type, const QString &param = QString());
+KALARMCAL_EXPORT Type    status(const KCalendarCore::Event::Ptr &, QString *param = nullptr);
+KALARMCAL_EXPORT void    setStatus(const KCalendarCore::Event::Ptr &, Type, const QString &param = QString());
 
 /** Return the alarm Type for a mime type string. */
 KALARMCAL_EXPORT Type    type(const QString &mimeType);
