@@ -2,7 +2,7 @@
  *  karecurrence.h  -  recurrence with special yearly February 29th handling
  *  This file is part of kalarmcal library, which provides access to KAlarm
  *  calendar data.
- *  Copyright © 2005-2012 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2005-2012 David Jarvie <djarvie@kde.org>
  *
  *  This library is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Library General Public License as published
@@ -82,7 +82,7 @@ public:
     };
 
     KARecurrence();
-    KARecurrence(const KCalendarCore::Recurrence &r);
+    KARecurrence(const KCalendarCore::Recurrence &r);   //krazy:exclude=explicit  Allow implicit conversion
     KARecurrence(const KARecurrence &r);
     ~KARecurrence();
 
@@ -90,7 +90,7 @@ public:
      * Assignment operator.
      * @param r the recurrence which will be assigned to this.
      */
-    KARecurrence &operator=(const KARecurrence &r);
+    KARecurrence &operator=(const KARecurrence &r) = delete;
 
     /**
      * Comparison operator for equality.
